@@ -6,26 +6,30 @@
 
 #pragma once
 
+#include <QPointer>
 #include <QQuickItem>
 #include <QVariant>
-#include <QPointer>
 
 class ContentItem;
 class ColumnView;
 
-class ScrollIntentionEvent : public QObject {
+class ScrollIntentionEvent : public QObject
+{
     Q_OBJECT
     Q_PROPERTY(QPointF delta MEMBER delta CONSTANT)
     Q_PROPERTY(bool accepted MEMBER accepted)
 public:
-    ScrollIntentionEvent(){}
-    ~ScrollIntentionEvent(){}
+    ScrollIntentionEvent()
+    {
+    }
+    ~ScrollIntentionEvent()
+    {
+    }
 
     QPointF delta;
     bool accepted = false;
 };
 
-
 /**
  * This is an attached property to every item that is inserted in the ColumnView,
  * used to access the view and page information such as the position and informations for layouting, such as fillWidth
@@ -79,7 +83,7 @@ public:
     ~ColumnViewAttached();
 
     void setIndex(int index);
-    int  index() const;
+    int index() const;
 
     void setFillWidth(bool fill);
     bool fillWidth() const;
@@ -90,7 +94,7 @@ public:
     ColumnView *view();
     void setView(ColumnView *view);
 
-    //Private API, not for QML use
+    // Private API, not for QML use
     QQuickItem *originalParent() const;
     void setOriginalParent(QQuickItem *parent);
 
@@ -251,14 +255,14 @@ class ColumnView : public QQuickItem
     /**
      * every item declared inside the view, both visual and non-visual items
      */
-    Q_PROPERTY(QQmlListProperty<QObject> contentData READ contentData  FINAL)
+    Q_PROPERTY(QQmlListProperty<QObject> contentData READ contentData FINAL)
     Q_CLASSINFO("DefaultProperty", "contentData")
 
 public:
     enum ColumnResizeMode {
         FixedColumns = 0,
         DynamicColumns,
-        SingleColumn
+        SingleColumn,
     };
     Q_ENUM(ColumnResizeMode)
 
@@ -291,12 +295,11 @@ public:
 
     QQuickItem *currentItem();
 
-    //NOTE: It's a QList<QObject *> as QML can't corectly build an Array out of QList<QQuickItem*>
+    // NOTE: It's a QList<QObject *> as QML can't corectly build an Array out of QList<QQuickItem*>
     QList<QObject *> visibleItems() const;
     QQuickItem *firstVisibleItem() const;
     QQuickItem *lastVisibleItem() const;
 
-
     QQuickItem *contentItem() const;
 
     QQmlListProperty<QQuickItem> contentChildren();
@@ -316,7 +319,7 @@ public:
     void setAcceptsMouse(bool accepts);
 
     // Api not intended for QML use
-    //can't do overloads in QML
+    // can't do overloads in QML
     QQuickItem *removeItem(QQuickItem *item);
     QQuickItem *removeItem(int item);
 
@@ -442,7 +445,6 @@ private:
     static QObject *contentData_at(QQmlListProperty<QObject> *prop, int index);
     static void contentData_clear(QQmlListProperty<QObject> *prop);
 
-
     QList<QObject *> m_contentData;
 
     ContentItem *m_contentItem;
