@@ -7,10 +7,10 @@
 
 #include "delegaterecycler.h"
 
+#include <QDebug>
 #include <QQmlComponent>
 #include <QQmlContext>
 #include <QQmlEngine>
-#include <QDebug>
 
 DelegateRecyclerAttached::DelegateRecyclerAttached(QObject *parent)
     : QObject(parent)
@@ -18,7 +18,8 @@ DelegateRecyclerAttached::DelegateRecyclerAttached(QObject *parent)
 }
 
 DelegateRecyclerAttached::~DelegateRecyclerAttached()
-{}
+{
+}
 /*
 void setRecycler(DelegateRecycler *recycler)
 {
@@ -31,8 +32,6 @@ DelegateRecycler *recycler() const
 }
 */
 
-
-
 class DelegateCache
 {
 public:
@@ -48,7 +47,7 @@ public:
 private:
     static const int s_cacheSize = 40;
     QHash<QQmlComponent *, int> m_refs;
-    QHash<QQmlComponent *, QList<QQuickItem *> > m_unusedItems;
+    QHash<QQmlComponent *, QList<QQuickItem *>> m_unusedItems;
 };
 
 Q_GLOBAL_STATIC(DelegateCache, s_delegateCache)
@@ -59,7 +58,7 @@ DelegateCache::DelegateCache()
 
 DelegateCache::~DelegateCache()
 {
-    for (auto& item : qAsConst(m_unusedItems)) {
+    for (auto &item : qAsConst(m_unusedItems)) {
         qDeleteAll(item);
     }
 }
@@ -86,7 +85,7 @@ void DelegateCache::deref(QQmlComponent *component)
 
 void DelegateCache::insert(QQmlComponent *component, QQuickItem *item)
 {
-    auto& items = m_unusedItems[component];
+    auto &items = m_unusedItems[component];
     if (items.length() >= s_cacheSize) {
         item->deleteLater();
         return;
@@ -94,7 +93,7 @@ void DelegateCache::insert(QQmlComponent *component, QQuickItem *item)
 
     DelegateRecyclerAttached *attached = qobject_cast<DelegateRecyclerAttached *>(qmlAttachedPropertiesObject<DelegateRecycler>(item, false));
     if (attached) {
-        emit attached->pooled();
+        Q_EMIT attached->pooled();
     }
 
     item->setParentItem(nullptr);
@@ -110,10 +109,6 @@ QQuickItem *DelegateCache::take(QQmlComponent *component)
     return nullptr;
 }
 
-
-
-
-
 DelegateRecycler::DelegateRecycler(QQuickItem *parent)
     : QQuickItem(parent)
 {
@@ -147,7 +142,7 @@ void DelegateRecycler::syncModel()
     QQmlContext *ctx = QQmlEngine::contextForObject(m_item)->parentContext();
     ctx->setContextProperty(QStringLiteral("model"), newModel);
 
-    //try to bind all properties
+    // try to bind all properties
     QObject *modelObj = newModel.value<QObject *>();
     if (modelObj) {
         const QMetaObject *metaObj = modelObj->metaObject();
@@ -165,7 +160,7 @@ void DelegateRecycler::syncModelProperties()
     }
     QQmlContext *ctx = QQmlEngine::contextForObject(m_item)->parentContext();
 
-    //try to bind all properties
+    // try to bind all properties
     QObject *modelObj = model.value<QObject *>();
     if (modelObj) {
         const QMetaObject *metaObj = modelObj->metaObject();
@@ -201,15 +196,26 @@ void DelegateRecycler::setSourceComponent(QQmlComponent *component)
     }
 
     if (!m_propertiesTracker) {
-        static QMap<QQmlEngine*, QQmlComponent*> propertiesTrackerComponent;
+        static QHash<QQmlEngine *, QQmlComponent *> propertiesTrackerComponent;
         auto engine = qmlEngine(this);
         auto it = propertiesTrackerComponent.find(engine);
         if (it == propertiesTrackerComponent.end()) {
-            connect(engine, &QObject::destroyed, engine, [engine] { propertiesTrackerComponent.remove(engine); });
+            connect(engine, &QObject::destroyed, engine, [engine] {
+                propertiesTrackerComponent.remove(engine);
+            });
             it = propertiesTrackerComponent.insert(engine, new QQmlComponent(engine, engine));
 
-            (*it)->setData(QByteArrayLiteral("import QtQuick 2.3\nQtObject{property int trackedIndex: index; property var trackedModel: typeof model != 'undefined' ? model : null; property var trackedModelData: typeof modelData != 'undefined' ? modelData : null}"), QUrl(QStringLiteral("delegaterecycler.cpp")));
+            /* clang-format off */
+            (*it)->setData(QByteArrayLiteral(R"(
+import QtQuick 2.3
+QtObject {
+    property int trackedIndex: index
+    property var trackedModel: typeof model != 'undefined' ? model : null
+    property var trackedModelData: typeof modelData != 'undefined' ? modelData : null
+}
+)"), QUrl(QStringLiteral("delegaterecycler.cpp")));
         }
+        /* clang-format on */
         m_propertiesTracker = (*it)->create(QQmlEngine::contextForObject(this));
 
         connect(m_propertiesTracker, SIGNAL(trackedIndexChanged()), this, SLOT(syncIndex()));
@@ -270,8 +276,7 @@ void DelegateRecycler::setSourceComponent(QQmlComponent *component)
                 QMetaProperty prop = metaObj->property(i);
                 ctx->setContextProperty(QString::fromUtf8(prop.name()), prop.read(modelObj));
                 if (prop.hasNotifySignal()) {
-                    QMetaMethod updateSlot = metaObject()->method(
-                    metaObject()->indexOfSlot("syncModelProperties()"));
+                    QMetaMethod updateSlot = metaObject()->method(metaObject()->indexOfSlot("syncModelProperties()"));
                     connect(modelObj, prop.notifySignal(), this, updateSlot);
                 }
             }
@@ -282,13 +287,13 @@ void DelegateRecycler::setSourceComponent(QQmlComponent *component)
         ctx->setContextProperty(QStringLiteral("index"), m_propertiesTracker->property("trackedIndex"));
         ctx->setContextProperty(QStringLiteral("delegateRecycler"), this);
 
-        QObject * obj = component->create(ctx);
+        QObject *obj = component->create(ctx);
         m_item = qobject_cast<QQuickItem *>(obj);
         if (!m_item) {
             obj->deleteLater();
         } else {
             connect(m_item.data(), &QObject::destroyed, ctx, &QObject::deleteLater);
-            //if the user binded an explicit width, consider it, otherwise base upon implicit
+            // if the user binded an explicit width, consider it, otherwise base upon implicit
             m_widthFromItem = m_item->width() > 0 && m_item->width() != m_item->implicitWidth();
             m_heightFromItem = m_item->height() > 0 && m_item->height() != m_item->implicitHeight();
 
@@ -302,14 +307,13 @@ void DelegateRecycler::setSourceComponent(QQmlComponent *component)
         syncModel();
 
         QQmlContext *ctx = QQmlEngine::contextForObject(m_item)->parentContext();
-        ctx->setContextProperties({ QQmlContext::PropertyPair{ QStringLiteral("modelData"), m_propertiesTracker->property("trackedModelData") },
-                                    QQmlContext::PropertyPair{ QStringLiteral("index"), m_propertiesTracker->property("trackedIndex")},
-                                    QQmlContext::PropertyPair{ QStringLiteral("delegateRecycler"), QVariant::fromValue<QObject*>(this) }
-                                 });
+        ctx->setContextProperties({QQmlContext::PropertyPair{QStringLiteral("modelData"), m_propertiesTracker->property("trackedModelData")},
+                                   QQmlContext::PropertyPair{QStringLiteral("index"), m_propertiesTracker->property("trackedIndex")},
+                                   QQmlContext::PropertyPair{QStringLiteral("delegateRecycler"), QVariant::fromValue<QObject *>(this)}});
 
         DelegateRecyclerAttached *attached = qobject_cast<DelegateRecyclerAttached *>(qmlAttachedPropertiesObject<DelegateRecycler>(m_item, false));
         if (attached) {
-            emit attached->reused();
+            Q_EMIT attached->reused();
         }
     }
 
@@ -321,7 +325,7 @@ void DelegateRecycler::setSourceComponent(QQmlComponent *component)
         updateSize(true);
     }
 
-    emit sourceComponentChanged();
+    Q_EMIT sourceComponentChanged();
 }
 
 void DelegateRecycler::resetSourceComponent()
@@ -368,7 +372,7 @@ void DelegateRecycler::updateSize(bool parentResized)
     const bool needToUpdateHeight = !m_heightFromItem && parentResized && heightValid();
 
     if (parentResized) {
-        m_item->setPosition(QPoint(0,0));
+        m_item->setPosition(QPoint(0, 0));
     }
     if (needToUpdateWidth && needToUpdateHeight) {
         m_item->setSize(QSizeF(width(), height()));
@@ -392,8 +396,7 @@ void DelegateRecycler::updateSize(bool parentResized)
     }
 
     setImplicitSize(m_item->implicitWidth() >= 0 ? m_item->implicitWidth() : m_item->width(),
-                m_item->implicitHeight() >= 0 ? m_item->implicitHeight() : m_item->height());
-
+                    m_item->implicitHeight() >= 0 ? m_item->implicitHeight() : m_item->height());
 
     m_updatingSize = false;
 }
