@@ -7,9 +7,9 @@
 #include "pagepool.h"
 
 #include <QDebug>
-#include <QQmlEngine>
 #include <QQmlComponent>
 #include <QQmlContext>
+#include <QQmlEngine>
 #include <QQmlProperty>
 
 PagePool::PagePool(QObject *parent)
@@ -42,7 +42,7 @@ void PagePool::setCachePages(bool cache)
     }
 
     m_cachePages = cache;
-    emit cachePagesChanged();
+    Q_EMIT cachePagesChanged();
 }
 
 bool PagePool::cachePages() const
@@ -55,8 +55,7 @@ QQuickItem *PagePool::loadPage(const QString &url, QJSValue callback)
     return loadPageWithProperties(url, QVariantMap(), callback);
 }
 
-QQuickItem *PagePool::loadPageWithProperties(
-        const QString &url, const QVariantMap &properties, QJSValue callback)
+QQuickItem *PagePool::loadPageWithProperties(const QString &url, const QVariantMap &properties, QJSValue callback)
 {
     Q_ASSERT(qmlEngine(this));
     QQmlContext *ctx = QQmlEngine::contextForObject(this);
@@ -72,14 +71,14 @@ QQuickItem *PagePool::loadPageWithProperties(
         if (callback.isCallable()) {
             QJSValueList args = {qmlEngine(this)->newQObject(found.value())};
             callback.call(args);
-            emit lastLoadedUrlChanged();
-            emit lastLoadedItemChanged();
+            Q_EMIT lastLoadedUrlChanged();
+            Q_EMIT lastLoadedItemChanged();
             // We could return the item, but for api coherence return null
             return nullptr;
 
         } else {
-            emit lastLoadedUrlChanged();
-            emit lastLoadedItemChanged();
+            Q_EMIT lastLoadedUrlChanged();
+            Q_EMIT lastLoadedItemChanged();
             return found.value();
         }
     }
@@ -97,8 +96,7 @@ QQuickItem *PagePool::loadPageWithProperties(
             return nullptr;
         }
 
-        connect(component, &QQmlComponent::statusChanged, this,
-                [this, component, callback, properties] (QQmlComponent::Status status) mutable {
+        connect(component, &QQmlComponent::statusChanged, this, [this, component, callback, properties](QQmlComponent::Status status) mutable {
             if (status != QQmlComponent::Ready) {
                 qWarning() << component->errors();
                 m_componentForUrl.remove(component->url());
@@ -136,12 +134,12 @@ QQuickItem *PagePool::loadPageWithProperties(
         QJSValueList args = {qmlEngine(this)->newQObject(item)};
         callback.call(args);
         m_lastLoadedUrl = actualUrl;
-        emit lastLoadedUrlChanged();
+        Q_EMIT lastLoadedUrlChanged();
         // We could return the item, but for api coherence return null
         return nullptr;
     } else {
         m_lastLoadedUrl = actualUrl;
-        emit lastLoadedUrlChanged();
+        Q_EMIT lastLoadedUrlChanged();
         return item;
     }
 }
@@ -151,7 +149,7 @@ QQuickItem *PagePool::createFromComponent(QQmlComponent *component, const QVaria
     QQmlContext *ctx = QQmlEngine::contextForObject(this);
     Q_ASSERT(ctx);
 
-    //TODO:  As soon as we can depend on Qt 5.14, use QQmlComponent::createWithInitialProperties
+    // TODO:  As soon as we can depend on Qt 5.14, use QQmlComponent::createWithInitialProperties
     QObject *obj = component->beginCreate(ctx);
 
     // Error?
@@ -160,7 +158,6 @@ QQuickItem *PagePool::createFromComponent(QQmlComponent *component, const QVaria
     }
 
     for (auto it = properties.constBegin(); it != properties.constEnd(); ++it) {
-
         QQmlProperty p(obj, it.key(), ctx);
         if (!p.isValid()) {
             qWarning() << "Invalid property " << it.key();
@@ -190,7 +187,7 @@ QQuickItem *PagePool::createFromComponent(QQmlComponent *component, const QVaria
         QQmlEngine::setObjectOwnership(item, QQmlEngine::JavaScriptOwnership);
     }
 
-    emit lastLoadedItemChanged();
+    Q_EMIT lastLoadedItemChanged();
 
     return item;
 }
@@ -273,12 +270,12 @@ void PagePool::deletePage(const QVariant &page)
 
 void PagePool::clear()
 {
-    for (auto *c : m_componentForUrl.values()) {
+    for (auto *c : qAsConst(m_componentForUrl)) {
         c->deleteLater();
     }
     m_componentForUrl.clear();
 
-    for (auto *i : m_itemForUrl.values()) {
+    for (auto *i : qAsConst(m_itemForUrl)) {
         // items that had been deparented are safe to delete
         if (!i->parentItem()) {
             i->deleteLater();
@@ -290,9 +287,9 @@ void PagePool::clear()
     m_urlForItem.clear();
     m_lastLoadedUrl = QUrl();
     m_lastLoadedItem = nullptr;
-    
-    emit lastLoadedUrlChanged();
-    emit lastLoadedItemChanged();
+
+    Q_EMIT lastLoadedUrlChanged();
+    Q_EMIT lastLoadedItemChanged();
 }
 
 #include "moc_pagepool.cpp"
