@@ -7,11 +7,12 @@
 #include "settings.h"
 
 #include <QDebug>
-#include <QStandardPaths>
-#include <QSettings>
 #include <QFile>
 #include <QGuiApplication>
 #include <QIcon>
+#include <QMouseEvent>
+#include <QSettings>
+#include <QStandardPaths>
 #include <QTouchDevice>
 #include <QWindow>
 
@@ -29,30 +30,27 @@ public:
 
 Q_GLOBAL_STATIC(SettingsSingleton, privateSettingsSelf)
 
-
 Settings::Settings(QObject *parent)
-    : QObject(parent),
-      m_hasTouchScreen(false),
-      m_hasTransientTouchInput(false)
+    : QObject(parent)
+    , m_hasTouchScreen(false)
+    , m_hasTransientTouchInput(false)
 {
     m_tabletModeAvailable = Kirigami::TabletModeWatcher::self()->isTabletModeAvailable();
-    connect(Kirigami::TabletModeWatcher::self(), &Kirigami::TabletModeWatcher::tabletModeAvailableChanged,
-            this, [this](bool tabletModeAvailable) {
-                setTabletModeAvailable(tabletModeAvailable);
-            });
+    connect(Kirigami::TabletModeWatcher::self(), &Kirigami::TabletModeWatcher::tabletModeAvailableChanged, this, [this](bool tabletModeAvailable) {
+        setTabletModeAvailable(tabletModeAvailable);
+    });
 
     m_tabletMode = Kirigami::TabletModeWatcher::self()->isTabletMode();
-    connect(Kirigami::TabletModeWatcher::self(), &Kirigami::TabletModeWatcher::tabletModeChanged,
-            this, [this](bool tabletMode) {
-                setTabletMode(tabletMode);
-            });
+    connect(Kirigami::TabletModeWatcher::self(), &Kirigami::TabletModeWatcher::tabletModeChanged, this, [this](bool tabletMode) {
+        setTabletMode(tabletMode);
+    });
 
-#if defined(Q_OS_ANDROID) || defined(Q_OS_IOS)
+#if defined(Q_OS_ANDROID) || defined(Q_OS_IOS) || defined(UBUNTU_TOUCH)
     m_mobile = true;
     m_hasTouchScreen = true;
 #else
-    //Mostly for debug purposes and for platforms which are always mobile,
-    //such as Plasma Mobile
+    // Mostly for debug purposes and for platforms which are always mobile,
+    // such as Plasma Mobile
     if (qEnvironmentVariableIsSet("QT_QUICK_CONTROLS_MOBILE")) {
         m_mobile = QByteArrayList{"1", "true"}.contains(qgetenv("QT_QUICK_CONTROLS_MOBILE"));
     } else {
@@ -67,12 +65,11 @@ Settings::Settings(QObject *parent)
         }
     }
     if (m_hasTouchScreen) {
-        connect(qApp, &QGuiApplication::focusWindowChanged,
-                this, [this](QWindow *win) {
-                    if (win) {
-                        win->installEventFilter(this);
-                    }
-                });
+        connect(qApp, &QGuiApplication::focusWindowChanged, this, [this](QWindow *win) {
+            if (win) {
+                win->installEventFilter(this);
+            }
+        });
     }
 #endif
 
@@ -86,7 +83,6 @@ Settings::Settings(QObject *parent)
     }
 }
 
-
 Settings::~Settings()
 {
 }
@@ -104,7 +100,13 @@ bool Settings::eventFilter(QObject *watched, QEvent *event)
         setTransientTouchInput(true);
         break;
     case QEvent::MouseButtonPress:
-    case QEvent::MouseMove:
+    case QEvent::MouseMove: {
+        QMouseEvent *me = static_cast<QMouseEvent *>(event);
+        if (me->source() == Qt::MouseEventNotSynthesized) {
+            setTransientTouchInput(false);
+        }
+        break;
+    }
     case QEvent::Wheel:
         setTransientTouchInput(false);
     default:
@@ -121,7 +123,7 @@ void Settings::setTabletModeAvailable(bool mobileAvailable)
     }
 
     m_tabletModeAvailable = mobileAvailable;
-    emit tabletModeAvailableChanged();
+    Q_EMIT tabletModeAvailableChanged();
 }
 
 bool Settings::isTabletModeAvailable() const
@@ -136,7 +138,7 @@ void Settings::setIsMobile(bool mobile)
     }
 
     m_mobile = mobile;
-    emit isMobileChanged();
+    Q_EMIT isMobileChanged();
 }
 
 bool Settings::isMobile() const
@@ -151,7 +153,7 @@ void Settings::setTabletMode(bool tablet)
     }
 
     m_tabletMode = tablet;
-    emit tabletModeChanged();
+    Q_EMIT tabletModeChanged();
 }
 
 bool Settings::tabletMode() const
@@ -167,7 +169,7 @@ void Settings::setTransientTouchInput(bool touch)
 
     m_hasTransientTouchInput = touch;
     if (!m_tabletMode) {
-        emit hasTransientTouchInputChanged();
+        Q_EMIT hasTransientTouchInputChanged();
     }
 }
 
@@ -198,13 +200,12 @@ QStringList Settings::information() const
         tr("KDE Frameworks %1").arg(QStringLiteral(KIRIGAMI2_VERSION_STRING)),
 #endif
         tr("The %1 windowing system").arg(QGuiApplication::platformName()),
-        tr("Qt %2 (built against %3)").arg(QString::fromLocal8Bit(qVersion()), QStringLiteral(QT_VERSION_STR))
-    };
+        tr("Qt %2 (built against %3)").arg(QString::fromLocal8Bit(qVersion()), QStringLiteral(QT_VERSION_STR))};
 }
 
 QVariant Settings::applicationWindowIcon() const
 {
-    const QIcon& windowIcon = qApp->windowIcon();
+    const QIcon &windowIcon = qApp->windowIcon();
     if (windowIcon.isNull()) {
         return QVariant();
     }
